@@ -186,6 +186,12 @@ if(subsites=="intergenic"){
   bial           <- bial[,inter,drop=FALSE]
   #object@Pop_FSTH$sites <- "intergenic"
 }
+
+if(subsites=="included" & length(bial!=0)){
+   included         <- which(object@region.data@included[[xx]]==TRUE)
+   bial             <- bial[,included,drop=FALSE]
+}
+
 }# End if subsites
 ############### ---------------------------------
 
